@@ -137,7 +137,10 @@ define ([
             'menuText': 'Privilege (status) history',
             'aclProfile': 'passerby',
             'start': dactionStart('actionPrivHistory'),
-            'pushable': false
+            // this starts the privhistory dtable, and if the dataset changes
+            // we might want to unwind the stack to this action to reset that
+            // dtable
+            'pushable': true
         });
         target.push('actionPrivHistoryEdit', { // read-write
             'name': 'actionPrivHistoryEdit',
@@ -227,7 +230,7 @@ define ([
             'name': 'actionSchedLookup',
             'type': 'daction',
             'menuText': 'Lookup',
-            'aclProfile': 'admin',
+            'aclProfile': 'inactive',
             'start': dactionStart('actionSchedLookup'),
             'pushable': false
         });
